@@ -9,6 +9,23 @@
 #ifndef __CONNECTION_H__
 #define __CONNECTION_H__
 
+#ifdef	__INCLUDE_POSTGRES_FE_H__ /* currently not defined */
+/*
+ *	Unfortunately #including postgres_fe.h causes various trobles.
+ */
+#include "postgres_fe.h"
+#else /* currently */
+#if defined(__GNUC__) || defined(__IBMC__)
+#define PG_PRINTF_ATTRIBUTE gnu_printf
+#define pg_attribute_printf(f,a) __attribute__((format(PG_PRINTF_ATTRIBUTE, f, a)))
+#else
+#define pg_attribute_printf(f,a)
+#endif	/* __GNUC__ || __IBMC__ */
+#endif	/* __INCLUDE_POSTGRES_FE_H__ */
+
+#include <libpq-fe.h>
+#include "pqexpbuffer.h"
+
 #include "psqlodbc.h"
 #include <time.h>
 
@@ -16,8 +33,6 @@
 #include <string.h>
 #include "descriptor.h"
 
-#include <libpq-fe.h>
-
 #if defined (POSIX_MULTITHREAD_SUPPORT)
 #include <pthread.h>
 #endif
@@ -426,7 +441,7 @@ void		CC_initialize_pg_version(ConnectionClass *conn);
 void		CC_log_error(const char *func, const char *desc, const ConnectionClass *self);
 int			CC_send_cancel_request(const ConnectionClass *conn);
 void		CC_on_commit(ConnectionClass *conn);
-void		CC_on_abort(ConnectionClass *conn, UDWORD opt);
+void		CC_on_abort(ConnectionClass *conn, unsigned int opt);
 void		CC_on_abort_partial(ConnectionClass *conn);
 void		ProcessRollback(ConnectionClass *conn, BOOL undo, BOOL partial);
 const char	*CC_get_current_schema(ConnectionClass *conn);
@@ -441,12 +456,20 @@ const		char *CurrCatString(const ConnectionClass *self);
 SQLUINTEGER	CC_get_isolation(ConnectionClass *self);
 
 SQLCHAR	*make_lstring_ifneeded(ConnectionClass *, const SQLCHAR *s, ssize_t len, BOOL);
+
+#define	TABLE_IS_VALID(tbname, tblen)	((tbname) && (tblen > 0 || SQL_NTS == tblen))
+int	schema_str(char *buf, int buflen, const SQLCHAR *s, SQLLEN len, BOOL table_is_valid, ConnectionClass *conn);
 char	*schema_strcat(char *buf, int buflen, const char *fmt, const SQLCHAR *s, SQLLEN len,
-		const SQLCHAR *, SQLLEN, ConnectionClass *conn);
+		BOOL table_is_valid, ConnectionClass *conn);
 char	*schema_strcat1(char *buf, int buflen, const char *fmt, const char *s1,
 				const char *s,
 				const SQLCHAR *, int, ConnectionClass *conn);
 
+void	schema_appendPQExpBuffer(PQExpBufferData *buf, const char *fmt, const SQLCHAR *s, SQLLEN len,
+		BOOL table_is_valid, ConnectionClass *conn);
+void	schema_appendPQExpBuffer1(PQExpBufferData *buf, const char *fmt, const char *s1, const char *s,
+				BOOL table_is_valid, ConnectionClass *conn);
+
 void	CC_examine_global_transaction(ConnectionClass *self);
 
 
