@@ -157,8 +157,6 @@ extern "C" {
 #define ABBR_SSLMODE			"CA"
 #define INI_EXTRAOPTIONS		"AB"
 #define INI_LOGDIR			"Logdir"
-#define INI_GSSAUTHUSEGSSAPI		"GssAuthUseGSS"
-#define ABBR_GSSAUTHUSEGSSAPI		"D0"
 #define INI_KEEPALIVETIME		"KeepaliveTime"
 #define ABBR_KEEPALIVETIME		"D1"
 #define INI_KEEPALIVEINTERVAL		"KeepaliveInterval"
@@ -212,7 +210,6 @@ extern "C" {
 #define BIT_BYTEAASLONGVARBINARY		(1L<<24)
 #define BIT_USESERVERSIDEPREPARE		(1L<<25)
 #define BIT_LOWERCASEIDENTIFIER			(1L<<26)
-#define BIT_GSSAUTHUSEGSSAPI			(1L<<27)
 
 #define EFFECTIVE_BIT_COUNT			28
 
@@ -262,7 +259,6 @@ extern "C" {
 #define DEFAULT_USESERVERSIDEPREPARE	1
 #define DEFAULT_LOWERCASEIDENTIFIER	0
 #define DEFAULT_SSLMODE			SSLMODE_DISABLE
-#define DEFAULT_GSSAUTHUSEGSSAPI	0
 
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 #define DEFAULT_XAOPT			1
