@@ -46,7 +46,7 @@ PGAPI_Prepare(HSTMT hstmt,
 	RETCODE	retval = SQL_SUCCESS;
 	BOOL	prepared;
 
-	mylog("%s: entering...\n", func);
+	MYLOG(0, "entering...\n");
 
 #define	return	DONT_CALL_RETURN_FROM_HERE???
 	/* StartRollbackState(self); */
@@ -62,30 +62,30 @@ PGAPI_Prepare(HSTMT hstmt,
 	switch (self->status)
 	{
 		case STMT_DESCRIBED:
-			mylog("**** PGAPI_Prepare: STMT_DESCRIBED, recycle\n");
+			MYLOG(0, "**** STMT_DESCRIBED, recycle\n");
 			SC_recycle_statement(self); /* recycle the statement, but do
 										 * not remove parameter bindings */
 			break;
 
 		case STMT_FINISHED:
-			mylog("**** PGAPI_Prepare: STMT_FINISHED, recycle\n");
+			MYLOG(0, "**** STMT_FINISHED, recycle\n");
 			SC_recycle_statement(self); /* recycle the statement, but do
 										 * not remove parameter bindings */
 			break;
 
 		case STMT_ALLOCATED:
-			mylog("**** PGAPI_Prepare: STMT_ALLOCATED, copy\n");
+			MYLOG(0, "**** STMT_ALLOCATED, copy\n");
 			self->status = STMT_READY;
 			break;
 
 		case STMT_READY:
-			mylog("**** PGAPI_Prepare: STMT_READY, change SQL\n");
+			MYLOG(0, "**** STMT_READY, change SQL\n");
 			if (NOT_YET_PREPARED != prepared)
 				SC_recycle_statement(self); /* recycle the statement */
 			break;
 
 		case STMT_EXECUTING:
-			mylog("**** PGAPI_Prepare: STMT_EXECUTING, error!\n");
+			MYLOG(0, "**** STMT_EXECUTING, error!\n");
 
 			SC_set_error(self, STMT_SEQUENCE_ERROR, "PGAPI_Prepare(): The handle does not point to a statement that is ready to be executed", func);
 
@@ -130,7 +130,7 @@ PGAPI_Prepare(HSTMT hstmt,
 
 cleanup:
 #undef	return
-inolog("SQLPrepare return=%d\n", retval);
+MYLOG(1, "leaving %d\n", retval);
 	return retval;
 }
 
@@ -147,7 +147,7 @@ PGAPI_ExecDirect(HSTMT hstmt,
 	CSTR func = "PGAPI_ExecDirect";
 	const ConnectionClass	*conn = SC_get_conn(stmt);
 
-	mylog("%s: entering...%x\n", func, flag);
+	MYLOG(0, "entering...%x\n", flag);
 
 	if (result = SC_initialize_and_recycle(stmt), SQL_SUCCESS != result)
 		return result;
@@ -157,14 +157,14 @@ PGAPI_ExecDirect(HSTMT hstmt,
 	 * execute this statement again
 	 */
 	stmt->statement = make_string(szSqlStr, cbSqlStr, NULL, 0);
-inolog("a2\n");
+MYLOG(1, "a2\n");
 	if (!stmt->statement)
 	{
 		SC_set_error(stmt, STMT_NO_MEMORY_ERROR, "No memory available to store statement", func);
 		return SQL_ERROR;
 	}
 
-	mylog("**** %s: hstmt=%p, statement='%s'\n", func, hstmt, stmt->statement);
+	MYLOG(0, "**** hstmt=%p, statement='%s'\n", hstmt, stmt->statement);
 
 	if (0 != (flag & PODBC_WITH_HOLD))
 		SC_set_with_hold(stmt);
@@ -188,11 +188,11 @@ inolog("a2\n");
 		return SQL_ERROR;
 	}
 
-	mylog("%s: calling PGAPI_Execute...\n", func);
+	MYLOG(0, "calling PGAPI_Execute...\n");
 
 	result = PGAPI_Execute(hstmt, flag);
 
-	mylog("%s: returned %hd from PGAPI_Execute\n", func, result);
+	MYLOG(0, "leaving %hd\n", result);
 	return result;
 }
 
@@ -420,7 +420,7 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, BOOL *exec_end)
 
 	*exec_end = FALSE;
 	conn = SC_get_conn(stmt);
-	mylog("%s: copying statement params: trans_status=%d, len=%d, stmt='%s'\n", func, conn->transact_status, strlen(stmt->statement), stmt->statement);
+	MYLOG(0, "copying statement params: trans_status=%d, len=" FORMAT_SIZE_T ", stmt='%s'\n", conn->transact_status, strlen(stmt->statement), stmt->statement);
 
 #define	return	DONT_CALL_RETURN_FROM_HERE???
 #define	RETURN(code)	{ retval = code; goto cleanup; }
@@ -432,7 +432,7 @@ RETCODE	Exec_with_parameters_resolved(StatementClass *stmt, BOOL *exec_end)
 	if (HowToPrepareBeforeExec(stmt, FALSE) >= allowParse)
 		prepare_before_exec = TRUE;
 
-inolog("prepare_before_exec=%d srv=%d\n", prepare_before_exec, conn->connInfo.use_server_side_prepare);
+MYLOG(1, "prepare_before_exec=%d srv=%d\n", prepare_before_exec, conn->connInfo.use_server_side_prepare);
 	/* Create the statement with parameters substituted. */
 	retval = copy_statement_with_parameters(stmt, prepare_before_exec);
 	stmt->current_exec_param = -1;
@@ -443,12 +443,12 @@ inolog("prepare_before_exec=%d srv=%d\n", prepare_before_exec, conn->connInfo.us
 		RETURN(retval) /* error msg is passed from the above */
 	}
 
-	mylog("   stmt_with_params = '%s'\n", stmt->stmt_with_params);
+	MYLOG(0, "   stmt_with_params = '%s'\n", stmt->stmt_with_params);
 
 	/*
 	 *	The real execution.
 	 */
-mylog("about to begin SC_execute\n");
+MYLOG(0, "about to begin SC_execute\n");
 	retval = SC_execute(stmt);
 	if (retval == SQL_ERROR)
 	{
@@ -549,12 +549,11 @@ cleanup:
 int
 StartRollbackState(StatementClass *stmt)
 {
-	CSTR	func = "StartRollbackState";
 	int			ret;
 	ConnectionClass	*conn;
 	ConnInfo	*ci = NULL;
 
-inolog("%s:%p->external=%d\n", func, stmt, stmt->external);
+MYLOG(1, "entering %p->external=%d\n", stmt, stmt->external);
 	conn = SC_get_conn(stmt);
 	if (conn)
 		ci = &conn->connInfo;
@@ -639,7 +638,7 @@ SetStatementSvp(StatementClass *stmt, unsigned int option)
 		ENTER_CONN_CS(conn);
 		conn->lock_CC_for_rb++;
 	}
-inolog(" !!!! %s:%p->accessed=%d opt=%u in_progress=%u prev=%u\n", __FUNCTION__, conn, CC_accessed_db(conn), option, conn->opt_in_progress, conn->opt_previous);
+MYLOG(1, " %p->accessed=%d opt=%u in_progress=%u prev=%u\n", conn, CC_accessed_db(conn), option, conn->opt_in_progress, conn->opt_previous);
 	conn->opt_in_progress &= option;
 	switch (stmt->statement_type)
 	{
@@ -682,7 +681,7 @@ inolog(" !!!! %s:%p->accessed=%d opt=%u in_progress=%u prev=%u\n", __FUNCTION__,
 		}
 	}
 	CC_set_accessed_db(conn);
-inolog("%s:%p->accessed=%d\n", func, conn, CC_accessed_db(conn));
+MYLOG(1, "leaving %p->accessed=%d\n", conn, CC_accessed_db(conn));
 	return ret;
 }
 
@@ -693,10 +692,10 @@ DiscardStatementSvp(StatementClass *stmt, RETCODE ret, BOOL errorOnly)
 	ConnectionClass	*conn = SC_get_conn(stmt);
 	BOOL	start_stmt = FALSE;
 
-inolog("%s:%p->accessed=%d is_in=%d is_rb=%d is_tc=%d\n", func, conn, CC_accessed_db(conn),
+MYLOG(1, "entering %p->accessed=%d is_in=%d is_rb=%d is_tc=%d\n", conn, CC_accessed_db(conn),
 CC_is_in_trans(conn), SC_is_rb_stmt(stmt), SC_is_tc_stmt(stmt));
 	if (conn->lock_CC_for_rb > 0)
-		mylog("%s:in_progress=%u previous=%d\n", func, conn->opt_in_progress, conn->opt_previous);
+		MYLOG(0, "in_progress=%u previous=%d\n", conn->opt_in_progress, conn->opt_previous);
 	switch (ret)
 	{
 		case SQL_NEED_DATA:
@@ -733,7 +732,7 @@ CC_is_in_trans(conn), SC_is_rb_stmt(stmt), SC_is_tc_stmt(stmt));
 	}
 	else if (errorOnly)
 		return ret;
-inolog("ret=%d\n", ret);
+MYLOG(1, "\tret=%d\n", ret);
 cleanup:
 #ifdef NOT_USED
 	if (!SC_is_prepare_statement(stmt) && ONCE_DESCRIBED == stmt->prepared)
@@ -751,10 +750,11 @@ cleanup:
 		{
 			LEAVE_CONN_CS(conn);
 			conn->lock_CC_for_rb--;
-			inolog(" %s:release conn_lock\n", __FUNCTION__);
+			MYLOG(1, " release conn_lock\n");
 		}
 		CC_start_stmt(conn);
 	}
+	MYLOG(1, "leaving %d\n", ret);
 	return ret;
 }
 
@@ -892,7 +892,7 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 	BOOL	exec_end, recycled = FALSE, recycle = TRUE;
 	SQLSMALLINT	num_params;
 
-	mylog("%s: entering...%x\n", func, flag);
+	MYLOG(0, "entering...%x\n", flag);
 
 	conn = SC_get_conn(stmt);
 	apdopts = SC_get_APDF(stmt);
@@ -907,13 +907,13 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 		SC_recycle_statement(stmt);
 	}
 
-	mylog("%s: clear errors...\n", func);
+	MYLOG(0, "clear errors...\n");
 
 	SC_clear_error(stmt);
 	if (!stmt->statement)
 	{
 		SC_set_error(stmt, STMT_NO_STMTSTRING, "This handle does not have a SQL statement stored in it", func);
-		mylog("%s: problem with handle\n", func);
+		MYLOG(0, "problem with handle\n");
 		return SQL_ERROR;
 	}
 
@@ -945,7 +945,7 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 	 */
 	else if (stmt->status == STMT_FINISHED)
 	{
-		mylog("%s: recycling statement (should have been done by app)...\n", func);
+		MYLOG(0, "recycling statement (should have been done by app)...\n");
 /******** Is this really NEEDED ? ******/
 		SC_recycle_statement(stmt);
 		recycled = TRUE;
@@ -955,7 +955,7 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 		(stmt->status != STMT_ALLOCATED && stmt->status != STMT_READY))
 	{
 		SC_set_error(stmt, STMT_STATUS_ERROR, "The handle does not point to a statement that is ready to be executed", func);
-		mylog("%s: problem with statement\n", func);
+		MYLOG(0, "problem with statement\n");
 		retval = SQL_ERROR;
 		goto cleanup;
 	}
@@ -988,7 +988,7 @@ PGAPI_Execute(HSTMT hstmt, UWORD flag)
 					break;
 			}
 		}
-mylog("prepareParameters was %s called, prepare state:%d\n", shouldParse == nCallParse ? "" : "not", stmt->prepare);
+MYLOG(0, "prepareParameters was %s called, prepare state:%d\n", shouldParse == nCallParse ? "" : "not", stmt->prepare);
 
 		if (shouldParse == nCallParse &&
 		    PREPARE_BY_THE_DRIVER == stmt->prepare)
@@ -1073,7 +1073,7 @@ next_param_row:
 			/* Check for data at execution parameters */
 			if (apdopts->parameters[i].data_at_exec)
 			{
-				mylog("The %dth parameter of %d-row is data at exec(%d)\n", i, current_row, pcVal ? (*pcVal) : -1);
+				MYLOG(0, "The " FORMAT_LEN "th parameter of " FORMAT_LEN "-row is data at exec(" FORMAT_LEN ")\n", i, current_row, pcVal ? (*pcVal) : -1);
 				if (stmt->data_at_exec < 0)
 					stmt->data_at_exec = 1;
 				else
@@ -1106,7 +1106,7 @@ next_param_row:
 		goto next_param_row;
 	}
 cleanup:
-mylog("retval=%d\n", retval);
+MYLOG(0, "leaving retval=%d\n", retval);
 	SC_setInsertedTable(stmt, retval);
 #undef	return
 	return retval;
@@ -1123,7 +1123,7 @@ PGAPI_Transact(HENV henv,
 	char		ok;
 	int			lf;
 
-	mylog("entering %s: hdbc=%p, henv=%p\n", func, hdbc, henv);
+	MYLOG(0, "entering hdbc=%p, henv=%p\n", hdbc, henv);
 
 	if (hdbc == SQL_NULL_HDBC && henv == SQL_NULL_HENV)
 	{
@@ -1162,7 +1162,7 @@ PGAPI_Transact(HENV henv,
 	/* If manual commit and in transaction, then proceed. */
 	if (CC_loves_visible_trans(conn) && CC_is_in_trans(conn))
 	{
-		mylog("PGAPI_Transact: sending on conn %p '%d'\n", conn, fType);
+		MYLOG(0, "sending on conn %p '%d'\n", conn, fType);
 
 		ok = (SQL_COMMIT == fType) ? CC_commit(conn) : CC_abort(conn);
 		if (!ok)
@@ -1185,7 +1185,7 @@ PGAPI_Cancel(HSTMT hstmt)		/* Statement to cancel. */
 	ConnectionClass *conn;
 	RETCODE		ret = SQL_SUCCESS;
 
-	mylog("%s: entering...\n", func);
+	MYLOG(0, "entering...\n");
 
 	/* Check if this can handle canceling in the middle of a SQLPutData? */
 	if (!stmt)
@@ -1282,7 +1282,7 @@ PGAPI_NativeSql(HDBC hdbc,
 	ConnectionClass *conn = (ConnectionClass *) hdbc;
 	RETCODE		result;
 
-	mylog("%s: entering...cbSqlStrIn=%d\n", func, cbSqlStrIn);
+	MYLOG(0, "entering...cbSqlStrIn=%d\n", cbSqlStrIn);
 
 	ptr = (cbSqlStrIn == 0) ? "" : make_string(szSqlStrIn, cbSqlStrIn, NULL, 0);
 	if (!ptr)
@@ -1332,13 +1332,13 @@ PGAPI_ParamData(HSTMT hstmt,
 	Int2		num_p;
 	ConnectionClass	*conn = NULL;
 
-	mylog("%s: entering...\n", func);
+	MYLOG(0, "entering...\n");
 
 	conn = SC_get_conn(stmt);
 
 	estmt = stmt->execute_delegate ? stmt->execute_delegate : stmt;
 	apdopts = SC_get_APDF(estmt);
-	mylog("%s: data_at_exec=%d, params_alloc=%d\n", func, estmt->data_at_exec, apdopts->allocated);
+	MYLOG(0, "\tdata_at_exec=%d, params_alloc=%d\n", estmt->data_at_exec, apdopts->allocated);
 
 #define	return	DONT_CALL_RETURN_FROM_HERE???
 	if (SC_AcceptedCancelRequest(stmt))
@@ -1381,7 +1381,7 @@ PGAPI_ParamData(HSTMT hstmt,
 
 	/* Done, now copy the params and then execute the statement */
 	ipdopts = SC_get_IPDF(estmt);
-inolog("ipdopts=%p\n", ipdopts);
+MYLOG(1, "ipdopts=%p\n", ipdopts);
 	if (estmt->data_at_exec == 0)
 	{
 		BOOL	exec_end;
@@ -1414,16 +1414,16 @@ inolog("ipdopts=%p\n", ipdopts);
 	num_p = estmt->num_params;
 	if (num_p < 0)
 		PGAPI_NumParams(estmt, &num_p);
-inolog("i=%d allocated=%d num_p=%d\n", i, apdopts->allocated, num_p);
+MYLOG(1, "i=%d allocated=%d num_p=%d\n", i, apdopts->allocated, num_p);
 	if (num_p > apdopts->allocated)
 		num_p = apdopts->allocated;
 	/* At least 1 data at execution parameter, so Fill in the token value */
 	for (; i < num_p; i++)
 	{
-inolog("i=%d", i);
+MYLOG(1, "i=%d", i);
 		if (apdopts->parameters[i].data_at_exec)
 		{
-inolog(" at exec buffer=%p", apdopts->parameters[i].buffer);
+MYPRINTF(1, " at exec buffer=%p", apdopts->parameters[i].buffer);
 			estmt->data_at_exec--;
 			estmt->current_exec_param = i;
 			estmt->put_data = FALSE;
@@ -1435,7 +1435,7 @@ inolog(" at exec buffer=%p", apdopts->parameters[i].buffer);
 					SQLULEN	offset = apdopts->param_offset_ptr ? *apdopts->param_offset_ptr : 0;
 					SQLLEN	perrow = apdopts->param_bind_type > 0 ? apdopts->param_bind_type : apdopts->parameters[i].buflen;
 
-inolog(" offset=%d perrow=%d", offset, perrow);
+MYPRINTF(1, " offset=" FORMAT_LEN " perrow=" FORMAT_LEN, offset, perrow);
 					*prgbValue = apdopts->parameters[i].buffer + offset + estmt->exec_current_row * perrow;
 				}
 				else
@@ -1443,15 +1443,15 @@ inolog(" offset=%d perrow=%d", offset, perrow);
 			}
 			break;
 		}
-inolog("\n");
+MYPRINTF(1, "\n");
 	}
 
 	retval = SQL_NEED_DATA;
-inolog("return SQL_NEED_DATA\n");
+MYLOG(1, "return SQL_NEED_DATA\n");
 cleanup:
 #undef	return
 	SC_setInsertedTable(stmt, retval);
-	mylog("%s: returning %d\n", func, retval);
+	MYLOG(0, "leaving %d\n", retval);
 	return retval;
 }
 
@@ -1481,7 +1481,7 @@ PGAPI_PutData(HSTMT hstmt,
 	SQLLEN		putlen;
 	BOOL		lenset = FALSE, handling_lo = FALSE;
 
-	mylog("%s: entering...\n", func);
+	MYLOG(0, "entering...\n");
 
 #define	return	DONT_CALL_RETURN_FROM_HERE???
 	if (SC_AcceptedCancelRequest(stmt))
@@ -1562,7 +1562,7 @@ PGAPI_PutData(HSTMT hstmt,
 
 	if (!estmt->put_data)
 	{							/* first call */
-		mylog("PGAPI_PutData: (1) cbValue = %d\n", cbValue);
+		MYLOG(0, "(1) cbValue = " FORMAT_LEN "\n", cbValue);
 
 		estmt->put_data = TRUE;
 
@@ -1622,7 +1622,7 @@ PGAPI_PutData(HSTMT hstmt,
 			}
 
 			retval = odbc_lo_write(conn, estmt->lobj_fd, putbuf, (Int4) putlen);
-			mylog("lo_write: cbValue=%d, wrote %d bytes\n", putlen, retval);
+			MYLOG(0, "lo_write: cbValue=" FORMAT_LEN ", wrote %d bytes\n", putlen, retval);
 		}
 		else
 		{
@@ -1640,14 +1640,14 @@ PGAPI_PutData(HSTMT hstmt,
 	else
 	{
 		/* calling SQLPutData more than once */
-		mylog("PGAPI_PutData: (>1) cbValue = %d\n", cbValue);
+		MYLOG(0, "(>1) cbValue = " FORMAT_LEN "\n", cbValue);
 
 		/* if (current_iparam->SQLType == SQL_LONGVARBINARY) */
 		if (handling_lo)
 		{
 			/* the large object fd is in EXEC_buffer */
 			retval = odbc_lo_write(conn, estmt->lobj_fd, putbuf, (Int4) putlen);
-			mylog("lo_write(2): cbValue = %d, wrote %d bytes\n", putlen, retval);
+			MYLOG(0, "lo_write(2): cbValue = " FORMAT_LEN ", wrote %d bytes\n", putlen, retval);
 
 			*current_pdata->EXEC_used += putlen;
 		}
@@ -1661,7 +1661,7 @@ PGAPI_PutData(HSTMT hstmt,
 				char *buffer;
 
 				for (allocsize = (1 << 4); allocsize <= used; allocsize <<= 1) ;
-				mylog("        cbValue = %d, old_pos = %d, *used = %d\n", putlen, old_pos, used);
+				MYLOG(0, "        cbValue = " FORMAT_LEN ", old_pos = " FORMAT_LEN ", *used = " FORMAT_LEN "\n", putlen, old_pos, used);
 
 				/* dont lose the old pointer in case out of memory */
 				buffer = realloc(current_pdata->EXEC_buffer, allocsize);
