@@ -122,7 +122,7 @@ make_string(const SQLCHAR *s, SQLINTEGER len, char *buf, size_t bufsize)
 		length = strlen((char *) s);
 	else
 	{
-		mylog("make_string invalid length=%d\n", len);
+		MYLOG(0, "invalid length=%d\n", len);
 		return NULL;
 	}
 	if (buf)
@@ -131,9 +131,9 @@ make_string(const SQLCHAR *s, SQLINTEGER len, char *buf, size_t bufsize)
 		return buf;
 	}
 
-inolog("malloc size=%d\n", length);
+MYLOG(1, "malloc size=" FORMAT_SIZE_T "\n", length);
 	str = malloc(length + 1);
-inolog("str=%p\n", str);
+MYLOG(1, "str=%p\n", str);
 	if (!str)
 		return NULL;
 
