@@ -41,6 +41,10 @@
 #include <stdlib.h>
 #endif /* WIN32 */
 
+#ifndef	__GNUC__
+#define	__attribute__(x)
+#endif /* __GNUC__ */
+
 #ifdef	_MEMORY_DEBUG_
 void		*pgdebug_alloc(size_t);
 void		*pgdebug_calloc(size_t, size_t);
@@ -149,9 +153,11 @@ typedef	UInt4	OID;
 #ifdef	_WIN64
 #define	FORMAT_LEN	"%I64d" /* SQLLEN */
 #define	FORMAT_ULEN	"%I64u" /* SQLULEN */
+#define	FORMAT_POSIROW	"%I64u"
 #else /* _WIN64 */
 #define	FORMAT_LEN	"%ld"	/* SQLLEN */
 #define	FORMAT_ULEN	"%lu"	/* SQLULEN */
+#define	FORMAT_POSIROW	"%hu"
 #endif /* _WIN64 */
 #else /* WIN32 */
 #define	FORMAT_SIZE_T	"%zu"	/* size_t */
@@ -199,7 +205,15 @@ typedef	unsigned long long ULONG_PTR;
 #define	FORMAT_ULEN	"%lu"	/* SQLULEN */
 #endif /* HAVE_LONG_LONG */
 #endif /* SIZEOF_LONG */
+ 
+#if (SIZEOF_VOID_P == 8) && !defined(WITH_IODBC)
+#define	FORMAT_POSIROW	FORMAT_ULEN
+#else
+#define	FORMAT_POSIROW	"%u"
+#endif
+
 #endif /* WIN32 */
+
 #define	CAST_PTR(type, ptr)	(type)((LONG_PTR)(ptr))
 #define	CAST_UPTR(type, ptr)	(type)((ULONG_PTR)(ptr))
 #ifndef	SQL_IS_LEN
@@ -238,6 +252,7 @@ typedef double SDOUBLE;
 extern int posix_snprintf(char *buf, size_t size, const char *format, ...);
 #endif /* _MSC_VER */
 
+
 #ifndef strdup
 #define strdup _strdup
 #endif /* strdup */
@@ -601,7 +616,6 @@ typedef struct
 	signed char	accessible_only;
 	signed char	ignore_round_trip_time;
 	signed char	disable_keepalive;
-	signed char	gssauth_use_gssapi;
 	signed char	wcs_debug;
 	UInt4		extra_opts;
 	Int4		keepalive_idle;
@@ -622,6 +636,7 @@ enum { /* CC_conninfo_init option */
 void	CC_conninfo_init(ConnInfo *conninfo, UInt4 option);
 void	CC_conninfo_release(ConnInfo *conninfo);
 void	CC_copy_conninfo(ConnInfo *ci, const ConnInfo *sci);
+const char *GetExeProgramName();
 #ifdef	POSIX_MULTITHREAD_SUPPORT
 #if	!defined(HAVE_ECO_THREAD_LOCKS)
 #define	POSIX_THREADMUTEX_SUPPORT
